
#' predictive QQ-plot

#' pqq_plot
#' @param df data.frame with columns 'method' and 'pvalue'
#' @param DESKTOP boolean
#' @param path path tempdir() by default
#' @param name name to be added to the filename
#' @param width_mm width in mm, 200 by default
#' @param height_mm height in mm, 200 by default
#' @keywords batqa
#' @export
#' @examples
#' \dontrun{
#' pqq_plot()
#' }
#
pqq_plot <- function(df,DESKTOP=TRUE,path=tempdir(),name=NULL,width_mm=200,height_mm=200){

  if (!DESKTOP) {

      filename <- normalizePath(file.path(path,paste0("pqq_plot_",name,".tiff")),mustWork = FALSE)

      grDevices::tiff(filename = filename, width = width_mm, height = height_mm,
            units = "mm", pointsize = 12,
            compression = "lzw",
            bg = "transparent", res = 300)

  } else grDevices::dev.new()

  df <- df %>% group_by(method) %>% arrange(pvalue) %>% mutate(U = seq(1:n())/n())

  p <- ggplot2::ggplot(df, ggplot2::aes(x = U, y = pvalue)) +
         ggplot2::geom_abline(lty = "dashed", col = "red") +
         ggplot2::geom_point(ggplot2::aes(colour = method)) +
         #ggplot2::scale_colour_gradient(low = "white", high = "black") +
         ggplot2::coord_fixed(ratio = 1) +
         ggplot2::labs(
        x = "U[0,1]",
        y = "p-value"
      )

  print(p)

  if (!DESKTOP) {
    grDevices::dev.off()
    return(filename)
  } else {
    return(TRUE)
  }

}
