
#' fit_ranger

#' fit_ranger
#' Fitting a Ranger RF
#' @param dataset dataset with target, Predictors
#' @param target column name of the target
#' @param predictors predictors
#' @keywords cipred
#' @export
#' @examples
#' \dontrun{
#' fit_ranger()
#' }
#
fit_ranger <- function(dataset,target,predictors){

  predictors_ <- paste(predictors, collapse = "+")
  rf_formula <- stats::as.formula(paste(target, predictors_, sep = " ~ "))

  res <- ranger::ranger(formula=rf_formula, data=dataset, num.tree=500,importance='impurity',keep.inbag=TRUE)
  # rem: importance Variable importance mode, one of 'none', 'impurity', 'impurity_corrected', 'permutation'.
  # The 'impurity' measure is the Gini index for classification, the variance of the responses for regression and the sum of test statistics (see \code{splitrule}) for survival.
  return(res)
}


#' predict_ranger

#' predict_ranger
#' Predicting a Ranger RF
#' @param object ranger model
#' @param dataset dataset with target, Predictors
#' @keywords cipred
#' @export
#' @examples
#' \dontrun{
#' predict_ranger()
#' }
#
predict_ranger <- function(object,dataset){
  res <- stats::predict(object=object ,tibble::as_tibble(dataset),type="se",se.method='infjack')
  return(res)
}
