
#' fit_RF_batea

#' fit_RF_batea
#' @param train train dataset list or tibble
#' @param test test dataset list or tibble
#' @param target column name of the target
#' @param predictors column names of the predictors
#' @param batea_type chosen BATEA type 'r','or','sor','isor'
#' @param alg algorithm name for the BATEA optimisation
#' @param niter number of iteration for the optimisation
#' @keywords batqa
#' @export
#' @examples
#' \dontrun{
#' fit_batea()
#' }
#
fit_RF_batea <- function(train,test,target,predictors,batea_type,alg,niter){

  predict_ranger_local <- function(object,dataset){
    res <- stats::predict(object=object ,tibble::as_tibble(dataset),type="response")$prediction
    return(res)
  }

  res <- batqa::fit_batea(train = train,test = test, target = target, predictors = predictors, FUN_fit = fit_ranger,
                          FUN_predict = predict_ranger_local, batea_type=batea_type,alg=alg,niter=niter,
                          hyperpar=list(
                                phi_f1 = list(mean=4.35/100/1.96,sd=3/100),
                                phi_g1 = list(mean=4.35/100/1.96,sd=3/100),
                                phi_h1 = list(mean=0.1,sd=0.1),
                                beta_r  = list(mean=1,sd=2),
                                sig_r  = list(df=1,scale=0.2)),
                          burnin=30,
                          BURNIN=TRUE)
  return(res)
}
